@@ -4,8 +4,8 @@
 ( cd opt/kde/share/doc/HTML/de/kdf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kig ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/ktuberling ; rm -rf common )
@@ -20,14 +20,14 @@
 ( cd opt/kde/share/doc/HTML/de/kdat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kdvi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kgeo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kgeo ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kget ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kgpg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmid ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmid ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmix ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kodo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kodo ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kolf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kolf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpat ; rm -rf common )
@@ -36,6 +36,8 @@
 ( cd opt/kde/share/doc/HTML/de/korn ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kppp ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/krdc ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/krec ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/krec ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/krfb ; rm -rf common )
@@ -46,6 +48,8 @@
 ( cd opt/kde/share/doc/HTML/de/ksim ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/lisa ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/lisa ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kxkb ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kalzium ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/katomic ; rm -rf common )
@@ -90,8 +94,6 @@
 ( cd opt/kde/share/doc/HTML/de/kjots ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmail ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmail ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kmidi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kmidi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmoon ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/knode ; rm -rf common )
@@ -114,6 +116,8 @@
 ( cd opt/kde/share/doc/HTML/de/kwin4 ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/lskat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klipper ; rm -rf common )
@@ -124,8 +128,14 @@
 ( cd opt/kde/share/doc/HTML/de/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kompare ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kontact ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konsole ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpackage ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/khelpcenter/faq ; rm -rf common )
@@ -150,10 +160,10 @@
 ( cd opt/kde/share/doc/HTML/de/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kverbos ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kwallet ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kwuftpd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmenuedit ; rm -rf common )
@@ -164,12 +174,8 @@
 ( cd opt/kde/share/doc/HTML/de/flashkard ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/aktion ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/aktion ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kxconfig ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kxconfig ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf qpl-license.html )
@@ -206,6 +212,8 @@
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf doxygen.css )
@@ -220,12 +228,16 @@
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license.html )
@@ -300,10 +312,14 @@
 ( cd opt/kde/share/doc/HTML/de/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/passwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/background ; rm -rf common )
@@ -358,18 +374,12 @@
 ( cd opt/kde/share/doc/HTML/de/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmtaskbar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kthememgr ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/artsbuilder ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kbabel ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kbabel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kalarm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kalarm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kamera ; rm -rf common )
@@ -378,8 +388,12 @@
 ( cd opt/kde/share/doc/HTML/de/kdeprint ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kasteroids ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kbruch ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/keduca ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kgamma ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kicker ; rm -rf common )
@@ -396,6 +410,8 @@
 ( cd opt/kde/share/doc/HTML/de/kpager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpaint ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kopete ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpilot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kpilot ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kpoker ; rm -rf common )
@@ -416,8 +432,6 @@
 ( cd opt/kde/share/doc/HTML/de/ktouch ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kwrite ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/megami ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/megami ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kreversi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/noatun ; rm -rf common )
@@ -438,8 +452,6 @@
 ( cd opt/kde/share/doc/HTML/de/klettres ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/de/common common )
-( cd opt/kde/share/doc/HTML/de/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/de/kaphorism ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kghostview ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/klickety ; rm -rf common )
@@ -498,6 +510,8 @@
 ( cd opt/kde/share/doc/HTML/de/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/umbrello ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/konqueror ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/korganizer ; rm -rf common )
